# Table of Contents

- [migration-to-self-service-sso-configuration](<./migration-to-self-service-sso-configuration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Migration to the Self-Service SSO Configuration](<./Migration-to-the-Self-Service-SSO-Configuration.md>)
  - [Overview](<./Migration-to-the-Self-Service-SSO-Configuration/Overview.md>)
  - [Important Changes](<./Migration-to-the-Self-Service-SSO-Configuration/Important-Changes.md>)
  - [Prerequisites](<./Migration-to-the-Self-Service-SSO-Configuration/Prerequisites.md>)
  - [Configuration Options](<./Migration-to-the-Self-Service-SSO-Configuration/Configuration-Options.md>)
  - [Migration Process](<./Migration-to-the-Self-Service-SSO-Configuration/Migration-Process.md>)
  - [Step 1: Create a New Application in Your IdP for Each Workspace](<./Migration-to-the-Self-Service-SSO-Configuration/Step-1-Create-a-New-Application-in-Your-IdP-for-Each-Workspace.md>)
  - [Step 2: Configure SSO in Your IdP](<./Migration-to-the-Self-Service-SSO-Configuration/Step-2-Configure-SSO-in-Your-IdP.md>)
  - [Step 3: Upload Metadata to SAP LeanIX](<./Migration-to-the-Self-Service-SSO-Configuration/Step-3-Upload-Metadata-to-SAP-LeanIX.md>)
  - [Step 4: Test the Configuration](<./Migration-to-the-Self-Service-SSO-Configuration/Step-4-Test-the-Configuration.md>)
  - [Step 5: Enable the IdP](<./Migration-to-the-Self-Service-SSO-Configuration/Step-5-Enable-the-IdP.md>)
  - [Step 6: (Optional) Request to Add IdP Connection to a Custom Subdomain](<./Migration-to-the-Self-Service-SSO-Configuration/Step-6-Optional-Request-to-Add-IdP-Connection-to-a-Custom-Subdomain.md>)
  - [Troubleshooting](<./Migration-to-the-Self-Service-SSO-Configuration/Troubleshooting.md>)
  - [FAQs](<./Migration-to-the-Self-Service-SSO-Configuration/FAQs.md>)
  - [Related Resources](<./Migration-to-the-Self-Service-SSO-Configuration/Related-Resources.md>)
  - [Was this page helpful?](<./Migration-to-the-Self-Service-SSO-Configuration/Was-this-page-helpful.md>)
